| Title: | Ordered Panel |
|---|---|
| Description: | The ordered panel methodology (Zezulinski et al 2025 <doi:10.1159/000545366>) provides a structured framework for identifying and organizing sets of biomarkers, such as genetic variants, that distinguish between positive and negative subjects in a study when only a training cohort is available. This approach is particularly useful in situations where an independent validation cohort does not yet exist, rendering conventional performance metrics such as the receiver operating characteristic (ROC) curve and area under the ROC curve (AUC) inappropriate or potentially misleading. The methodology emphasizes transparent construction and evaluation of ordered signatures of biomarkers, allowing investigators to examine operating characteristics without establishing predictive performance. |
| Authors: | Tingting Zhan [aut, cre] (ORCID: <https://orcid.org/0000-0001-9971-4844>), Aejaz Sayeed [ctb] (ORCID: <https://orcid.org/0000-0001-6900-7524>) |
| Maintainer: | Tingting Zhan <[email protected]> |
| License: | GPL-2 |
| Version: | 0.1.1 |
| Built: | 2026-05-31 06:15:02 UTC |
| Source: | https://github.com/tingtingzhan/ordpanel |
The ordered panel methodology (Zezulinski et al 2025 doi:10.1159/000545366) provides a structured framework for identifying and organizing sets of biomarkers, such as genetic variants, that distinguish between positive and negative subjects in a study when only a training cohort is available. This approach is particularly useful in situations where an independent validation cohort does not yet exist, rendering conventional performance metrics such as the receiver operating characteristic (ROC) curve and area under the ROC curve (AUC) inappropriate or potentially misleading. The methodology emphasizes transparent construction and evaluation of ordered signatures of biomarkers, allowing investigators to examine operating characteristics without establishing predictive performance.
Maintainer: Tingting Zhan [email protected] (ORCID)
Authors:
Tingting Zhan [email protected] (ORCID)
Other contributors:
Aejaz Sayeed (ORCID) [contributor]
Useful links:
Visualize panellist using Package ggplot2
## S3 method for class 'panellist' autoplot(object, ...) ## S3 method for class 'panellist' autolayer(object, which = c("oc", "roc"), ...)## S3 method for class 'panellist' autoplot(object, ...) ## S3 method for class 'panellist' autolayer(object, which = c("oc", "roc"), ...)
object |
|
... |
additional parameters, currently no use |
which |
character scalar,
|
The S3 method autoplot.panellist() returns a ggplot object.
S4 Class panel
S4 Class panel
panel(m1 = zezulinski1, m0 = zezulinski0)panel(m1 = zezulinski1, m0 = zezulinski0)
m1, m0
|
see detailed explanations in Section Slots. |
The function panel() returns an R object of S4 class panel.
m1,m0logical matrix-es, true and false positives, respectively.
In other words, the variants tested positive in the positive and negative subjects (patients), respectively.
Rows are different variants. Columns are different subjects.
The rownames of m0 and m1 must be the same.
idorderedlabel(optional) character scalar, a human-friendly description of the panel
consort(optional) data.frame to create a consort_plot
Data sets used as examples in package ordPanel.
zezulinski1 zezulinski0zezulinski1 zezulinski0
An object of class matrix (inherits from array) with 12877 rows and 50 columns.
An object of class matrix (inherits from array) with 12877 rows and 31 columns.
To create a flow-chart for the creation of an ordered panel.
## S3 method for class 'panel' plot(x, ...)## S3 method for class 'panel' plot(x, ...)
x |
an ordered panel |
... |
additional parameters of the function consort_plot,
except for |
The function plot.panel() returns
an R object of class 'consort'
(returned from the function consort_plot),
if the input panel has a non-default @consort slot;
an invisible NULL-value,
if the input panel has a default @consort slot.
To create flow-charts for the creation of an ordered panellist.
## S3 method for class 'panellist' plot(x, ...)## S3 method for class 'panellist' plot(x, ...)
x |
an ordered panellist |
... |
additional parameters for the function wrap_plots,
not for the function |
The function plot.panellist() returns
a patchwork,
(returned from the function wrap_plots),
if the input panellist has at least one panel
with a non-default @consort slot;
an invisible NULL-value,
if all panels in the input panellist have a default @consort slot.
To sort a panel by some given criterion.
## S3 method for class 'panel' sort_by(x, y, ...)## S3 method for class 'panel' sort_by(x, y, ...)
x |
|
y |
one-sided formula |
... |
additional parameters of order |
The S3 method sort_by.panel() returns an ordered panel.
## S3 method for class 'panel' subset(x, subset, append.label = FALSE, ...)## S3 method for class 'panel' subset(x, subset, append.label = FALSE, ...)
x |
|
subset |
R language object |
append.label |
logical scalar (default value |
... |
additional parameters, currently not in use |
The S3 method subset.panel() returns an R object of S4 class panel.
Number of True & False Positives
sum1(x) sum0(x) cumsum1(x) cumsum0(x)sum1(x) sum0(x) cumsum1(x) cumsum0(x)
x |
The functions sum1() and sum0() return
a integer vector.
The functions cumsum1() and cumsum0() return
a non-decreasing integer vector.