Type: Package
Title: Ordered Panel
Version: 0.1.1
Date: 2026-03-18
Description: The ordered panel methodology (Zezulinski et al 2025 <doi:10.1159/000545366>) provides a structured framework for identifying and organizing sets of biomarkers, such as genetic variants, that distinguish between positive and negative subjects in a study when only a training cohort is available. This approach is particularly useful in situations where an independent validation cohort does not yet exist, rendering conventional performance metrics such as the receiver operating characteristic (ROC) curve and area under the ROC curve (AUC) inappropriate or potentially misleading. The methodology emphasizes transparent construction and evaluation of ordered signatures of biomarkers, allowing investigators to examine operating characteristics without establishing predictive performance.
License: GPL-2
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.3
LazyData: true
LazyDataCompression: xz
URL: https://github.com/tingtingzhan/ordPanel, https://tingtingzhan-ordpanel.netlify.app
Depends: R (≥ 4.5.0)
Imports: cli, flextable, ggplot2, methods, consort, patchwork, scales
Suggests: testthat (≥ 3.0.0)
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-03-18 21:21:07 UTC; tingtingzhan
Author: Tingting Zhan ORCID iD [aut, cre], Aejaz Sayeed ORCID iD [ctb]
Maintainer: Tingting Zhan <tingtingzhan@gmail.com>
Repository: CRAN
Date/Publication: 2026-03-19 07:20:02 UTC

ordPanel: Ordered Panel

Description

The ordered panel methodology (Zezulinski et al 2025 doi:10.1159/000545366) provides a structured framework for identifying and organizing sets of biomarkers, such as genetic variants, that distinguish between positive and negative subjects in a study when only a training cohort is available. This approach is particularly useful in situations where an independent validation cohort does not yet exist, rendering conventional performance metrics such as the receiver operating characteristic (ROC) curve and area under the ROC curve (AUC) inappropriate or potentially misleading. The methodology emphasizes transparent construction and evaluation of ordered signatures of biomarkers, allowing investigators to examine operating characteristics without establishing predictive performance.

Author(s)

Maintainer: Tingting Zhan tingtingzhan@gmail.com (ORCID)

Other contributors:

See Also

Useful links:


Extract Rows of panel

Description

Extract Rows of panel

Usage

## S3 method for class 'panel'
x[i, ...]

Arguments

x

panel

i

logical vector, row indices

...

additional parameters, currently not in use

Value

The S3 method ⁠[.panel()⁠ returns a panel.


Visualize panellist using Package ggplot2

Description

Visualize panellist using Package ggplot2

Usage

## S3 method for class 'panellist'
autoplot(object, ...)

## S3 method for class 'panellist'
autolayer(object, which = c("oc", "roc"), ...)

Arguments

object

panellist

...

additional parameters, currently no use

which

character scalar, 'oc' (default value) or (faux) 'roc'

Value

The S3 method autoplot.panellist() returns a ggplot object.


S4 Class panel

Description

S4 Class panel

Usage

panel(m1 = zezulinski1, m0 = zezulinski0)

Arguments

m1, m0

see detailed explanations in Section Slots.

  • If both m1 and m0 are missing, then random logical matrix-es will be generated;

  • If one-and-only-one of m1 and m0 is missing, then the function panel() will stop.

Value

The function panel() returns an R object of S4 class panel.

Slots

m1,m0

logical matrix-es, true and false positives, respectively. In other words, the variants tested positive in the positive and negative subjects (patients), respectively. Rows are different variants. Columns are different subjects. The rownames of m0 and m1 must be the same.

id

list of character vectors

ordered

logical scalar, whether this is an ordered panel

label

(optional) character scalar, a human-friendly description of the panel

consort

(optional) data.frame to create a consort_plot


panellist

Description

To combine multiple panels.

Usage

panellist(...)

Arguments

...

one or more panels

Value

The function panellist() returns an S3 object of panellist, which inherits from the classes listof and list.


Data Sets in Package ordPanel

Description

Data sets used as examples in package ordPanel.

Usage

zezulinski1

zezulinski0

Format

An object of class matrix (inherits from array) with 12877 rows and 50 columns.

An object of class matrix (inherits from array) with 12877 rows and 31 columns.

References

doi:10.1159/000545366


Flow-Chart of Ordered panel

Description

To create a flow-chart for the creation of an ordered panel.

Usage

## S3 method for class 'panel'
plot(x, ...)

Arguments

x

an ordered panel

...

additional parameters of the function consort_plot, except for data, orders and side_box

Value

The function plot.panel() returns


Flow-Charts of Ordered panellist

Description

To create flow-charts for the creation of an ordered panellist.

Usage

## S3 method for class 'panellist'
plot(x, ...)

Arguments

x

an ordered panellist

...

additional parameters for the function wrap_plots, not for the function plot.panel()

Value

The function plot.panellist() returns


Show panel

Description

Show panel

Usage

## S4 method for signature 'panel'
show(object)

Arguments

object

panel

Value

The show method of panel class does not have a returned value.


Sort panel by Given Criterion

Description

To sort a panel by some given criterion.

Usage

## S3 method for class 'panel'
sort_by(x, y, ...)

Arguments

x

panel

y

one-sided formula

...

additional parameters of order

Value

The S3 method sort_by.panel() returns an ordered panel.


Select a subset of panel

Description

Select a subset of panel

Usage

## S3 method for class 'panel'
subset(x, subset, append.label = FALSE, ...)

Arguments

x

panel

subset

R language object

append.label

logical scalar (default value FALSE), whether to append the subset-criterion to x@label

...

additional parameters, currently not in use

Value

The S3 method subset.panel() returns an R object of S4 class panel.


Number of True & False Positives

Description

Number of True & False Positives

Usage

sum1(x)

sum0(x)

cumsum1(x)

cumsum0(x)

Arguments

x

panel

Value

The functions sum1() and sum0() return a integer vector.

The functions cumsum1() and cumsum0() return a non-decreasing integer vector.