| Type: | Package |
| Title: | Ordered Panel |
| Version: | 0.1.1 |
| Date: | 2026-03-18 |
| Description: | The ordered panel methodology (Zezulinski et al 2025 <doi:10.1159/000545366>) provides a structured framework for identifying and organizing sets of biomarkers, such as genetic variants, that distinguish between positive and negative subjects in a study when only a training cohort is available. This approach is particularly useful in situations where an independent validation cohort does not yet exist, rendering conventional performance metrics such as the receiver operating characteristic (ROC) curve and area under the ROC curve (AUC) inappropriate or potentially misleading. The methodology emphasizes transparent construction and evaluation of ordered signatures of biomarkers, allowing investigators to examine operating characteristics without establishing predictive performance. |
| License: | GPL-2 |
| Encoding: | UTF-8 |
| Language: | en-US |
| RoxygenNote: | 7.3.3 |
| LazyData: | true |
| LazyDataCompression: | xz |
| URL: | https://github.com/tingtingzhan/ordPanel, https://tingtingzhan-ordpanel.netlify.app |
| Depends: | R (≥ 4.5.0) |
| Imports: | cli, flextable, ggplot2, methods, consort, patchwork, scales |
| Suggests: | testthat (≥ 3.0.0) |
| Config/testthat/edition: | 3 |
| NeedsCompilation: | no |
| Packaged: | 2026-03-18 21:21:07 UTC; tingtingzhan |
| Author: | Tingting Zhan |
| Maintainer: | Tingting Zhan <tingtingzhan@gmail.com> |
| Repository: | CRAN |
| Date/Publication: | 2026-03-19 07:20:02 UTC |
ordPanel: Ordered Panel
Description
The ordered panel methodology (Zezulinski et al 2025 doi:10.1159/000545366) provides a structured framework for identifying and organizing sets of biomarkers, such as genetic variants, that distinguish between positive and negative subjects in a study when only a training cohort is available. This approach is particularly useful in situations where an independent validation cohort does not yet exist, rendering conventional performance metrics such as the receiver operating characteristic (ROC) curve and area under the ROC curve (AUC) inappropriate or potentially misleading. The methodology emphasizes transparent construction and evaluation of ordered signatures of biomarkers, allowing investigators to examine operating characteristics without establishing predictive performance.
Author(s)
Maintainer: Tingting Zhan tingtingzhan@gmail.com (ORCID)
Other contributors:
Aejaz Sayeed (ORCID) [contributor]
See Also
Useful links:
Extract Rows of panel
Description
Extract Rows of panel
Usage
## S3 method for class 'panel'
x[i, ...]
Arguments
x |
|
i |
|
... |
additional parameters, currently not in use |
Value
The S3 method [.panel() returns a panel.
Visualize panellist using Package ggplot2
Description
Visualize panellist using Package ggplot2
Usage
## S3 method for class 'panellist'
autoplot(object, ...)
## S3 method for class 'panellist'
autolayer(object, which = c("oc", "roc"), ...)
Arguments
object |
|
... |
additional parameters, currently no use |
which |
character scalar,
|
Value
The S3 method autoplot.panellist() returns a ggplot object.
S4 Class panel
Description
S4 Class panel
Usage
panel(m1 = zezulinski1, m0 = zezulinski0)
Arguments
m1, m0 |
see detailed explanations in Section Slots. |
Value
The function panel() returns an R object of S4 class panel.
Slots
m1,m0logical matrix-es, true and false positives, respectively. In other words, the variants tested positive in the positive and negative subjects (patients), respectively. Rows are different variants. Columns are different subjects. The rownames of
m0andm1must be the same.idorderedlabel(optional) character scalar, a human-friendly description of the panel
consort(optional) data.frame to create a consort_plot
panellist
Description
To combine multiple panels.
Usage
panellist(...)
Arguments
... |
one or more panels |
Value
The function panellist() returns an S3 object of panellist,
which inherits from the classes listof and list.
Data Sets in Package ordPanel
Description
Data sets used as examples in package ordPanel.
Usage
zezulinski1
zezulinski0
Format
An object of class matrix (inherits from array) with 12877 rows and 50 columns.
An object of class matrix (inherits from array) with 12877 rows and 31 columns.
References
Flow-Chart of Ordered panel
Description
To create a flow-chart for the creation of an ordered panel.
Usage
## S3 method for class 'panel'
plot(x, ...)
Arguments
x |
an ordered panel |
... |
additional parameters of the function consort_plot,
except for |
Value
The function plot.panel() returns
an R object of class
'consort'(returned from the function consort_plot), if the input panel has a non-default@consortslot;an invisible
NULL-value, if the input panel has a default@consortslot.
Flow-Charts of Ordered panellist
Description
To create flow-charts for the creation of an ordered panellist.
Usage
## S3 method for class 'panellist'
plot(x, ...)
Arguments
x |
an ordered panellist |
... |
additional parameters for the function wrap_plots,
not for the function |
Value
The function plot.panellist() returns
a patchwork, (returned from the function wrap_plots), if the input panellist has at least one panel with a non-default
@consortslot;an invisible
NULL-value, if all panels in the input panellist have a default@consortslot.
Show panel
Description
Show panel
Usage
## S4 method for signature 'panel'
show(object)
Arguments
object |
Value
The show method of panel class does not have a returned value.
Sort panel by Given Criterion
Description
To sort a panel by some given criterion.
Usage
## S3 method for class 'panel'
sort_by(x, y, ...)
Arguments
x |
|
y |
one-sided formula |
... |
additional parameters of order |
Value
The S3 method sort_by.panel() returns an ordered panel.
Select a subset of panel
Description
Usage
## S3 method for class 'panel'
subset(x, subset, append.label = FALSE, ...)
Arguments
x |
|
subset |
R language object |
append.label |
logical scalar (default value |
... |
additional parameters, currently not in use |
Value
The S3 method subset.panel() returns an R object of S4 class panel.
Number of True & False Positives
Description
Number of True & False Positives
Usage
sum1(x)
sum0(x)
cumsum1(x)
cumsum0(x)
Arguments
x |
Value
The functions sum1() and sum0() return
a integer vector.
The functions cumsum1() and cumsum0() return
a non-decreasing integer vector.